@@ -31,7 +31,7 @@ from functools import partial
 
 
 __all__ = ["run", "shutdown_waits_for"]
-__version__ = "2021.8.1"
+__version__ = "2022.04.1"
 logger = logging.getLogger("aiorun")
 WINDOWS = sys.platform == "win32"
 
@@ -318,17 +318,15 @@ def run(
         return tasks, do_not_cancel
 
     tasks, do_not_cancel = sep()
-    # Here's a protip: if you group a bunch of tasks, and some of them
-    # get cancelled, and they DON'T HANDLE THE CANCELLATION, then the
-    # raised CancelledError will bubble up to, and stop the
-    # loop.run_until_complete() line: meaning, not all the tasks in
-    # the gathered group will actually be complete. You need to
-    # enable this with the ``return_exceptions`` flag.
-    group = gather(*tasks, *do_not_cancel, loop=loop, return_exceptions=True)
-    logger.info("Running pending tasks till complete")
-    # TODO: obtain all the results, and log any results that are exceptions
-    # other than CancelledError. Will be useful for troubleshooting.
-    loop.run_until_complete(group)
+     
+    async def wait_for_cancelled_tasks():
+        return await gather(*tasks, *do_not_cancel, return_exceptions=True)
+
+    if tasks or do_not_cancel:
+        logger.info("Running pending tasks till complete")
+        # TODO: obtain all the results, and log any results that are exceptions
+        # other than CancelledError. Will be useful for troubleshooting.
+        loop.run_until_complete(wait_for_cancelled_tasks())
 
     logger.info("Waiting for executor shutdown.")
     executor.shutdown(wait=True)
